@@ -76,7 +76,7 @@ __all__ = ["Texttable", "ArraySizeError"]
 
 __author__ = 'Gerome Fournier <jef(at)foutaise.org>'
 __license__ = 'LGPL'
-__version__ = '1.1.0'
+__version__ = '1.3.1'
 __credits__ = """\
 Jeff Kowalczyk:
     - textwrap improved import
@@ -105,22 +105,26 @@ frinkelpi:
 """
 
 import sys
-import string
 import unicodedata
 
+# define a text wrapping function to wrap some text
+# to a specific width:
+# - use cjkwrap if available (better CJK support)
+# - fallback to textwrap otherwise
 try:
-    if sys.version_info >= (2, 3):
-        import textwrap
-    elif sys.version_info >= (2, 2):
-        from optparse import textwrap
-    else:
-        from optik import textwrap
+    import cjkwrap
+    def textwrapper(txt, width):
+        return cjkwrap.wrap(txt, width)
 except ImportError:
-    sys.stderr.write("Can't import textwrap module!\n")
-    raise
+    try:
+        import textwrap
+        def textwrapper(txt, width):
+            return textwrap.wrap(txt, width)
+    except ImportError:
+        sys.stderr.write("Can't import textwrap module!\n")
+        raise
 
-if sys.version_info >= (2, 7):
-    from functools import reduce
+from functools import reduce
 
 if sys.version_info >= (3, 0):
     unicode_type = str
@@ -150,11 +154,8 @@ def len(iterable):
     """
     if isinstance(iterable, bytes_type) or isinstance(iterable, unicode_type):
         unicode_data = obj2unicode(iterable)
-        if hasattr(unicodedata, 'east_asian_width'):
-            w = unicodedata.east_asian_width
-            return sum([w(c) in 'WF' and 2 or (0 if unicodedata.combining(c) else 1) for c in unicode_data])
-        else:
-            return unicode_data.__len__()
+        w = unicodedata.east_asian_width
+        return sum([w(c) in 'WF' and 2 or (0 if unicodedata.combining(c) else 1) for c in unicode_data])
     else:
         return iterable.__len__()
 
@@ -278,7 +279,7 @@ class Texttable:
         """Set the desired columns datatype for the cols.
 
         - the elements of the array should be either a callable or any of
-          "a", "t", "f", "e", "i" or a callable:
+          "a", "t", "f", "e" or "i":
 
             * "a": automatic (try to use the most appropriate datatype)
             * "t": treat as text
@@ -400,7 +401,7 @@ class Texttable:
             raise FallbackToText()
         try:
             return float(x)
-        except ValueError:
+        except (TypeError, ValueError):
             raise FallbackToText()
 
     @classmethod
@@ -658,7 +659,7 @@ class Texttable:
                 if c.strip() == "":
                     array.append("")
                 else:
-                    array.extend(textwrap.wrap(c, width))
+                    array.extend(textwrapper(c, width))
             line_wrapped.append(array)
         max_cell_lines = reduce(max, list(map(len, line_wrapped)))
         for cell, valign in zip(line_wrapped, self._valign):
